@@ -1,7 +1,11 @@
 
-__version__ = "0.1.0"
+__version__ = "0.1.1"
 
-_services = __import__("continuous_services.services", globals(), locals(), ["*"])
+_services = None
+def _load_services():
+    global _services
+    if _services is None:
+        _services = __import__("continuous_services.services", globals(), locals(), ["*"])
 
 def get_class_name(module, guessed_class_name):
     guessed_lower = guessed_class_name.lower()
@@ -13,17 +17,21 @@ def get_class_name(module, guessed_class_name):
     return names[0]
 
 def get_service_class(service_name):
+    _load_services()
     module = getattr(_services, service_name)
     return getattr(module, get_class_name(module, "%sService" % service_name))
 
 def get_form_class(service_name):
+    _load_services()
     module = getattr(_services, service_name)
     return getattr(module, get_class_name(module, "%sForm" % service_name))
 
 def get_module(service_name):
+    _load_services()
     return getattr(_services, service_name)
 
 def get_modules():
+    _load_services()
     modules = []
     for service_name in _services.__all__:
         module = getattr(_services, service_name)
